@@ -1,13 +1,18 @@
+import hashlib
 import datetime
 import traceback
+import logging
 
 from smda.utility.FileLoader import FileLoader
+from smda.utility.MemoryFileLoader import MemoryFileLoader
 from smda.SmdaConfig import SmdaConfig
 from smda.common.BinaryInfo import BinaryInfo
 from smda.common.SmdaReport import SmdaReport
 from .intel.IntelDisassembler import IntelDisassembler
 from .ida.IdaExporter import IdaExporter
 
+LOGGER = logging.getLogger(__name__)
+
 class Disassembler(object):
 
     def __init__(self, config=None, backend="intel"):
@@ -38,6 +43,8 @@ class Disassembler(object):
         file_content = loader.getData()
         binary_info = BinaryInfo(file_content)
         binary_info.raw_data = loader.getRawData()
+        # we want the SHA256 of the unmapped file not how we mapped it to memory
+        binary_info.sha256 = hashlib.sha256(binary_info.raw_data).hexdigest()
         binary_info.file_path = file_path
         binary_info.base_addr = loader.getBaseAddress()
         binary_info.bitness = loader.getBitness()
@@ -49,7 +56,28 @@ class Disassembler(object):
             if self.config.STORE_BUFFER:
                 smda_report.buffer = file_content
         except Exception as exc:
-            print("-> an error occured (", str(exc), ").")
+            LOGGER.error("An error occurred while disassembling file.")
+            # print("-> an error occured (", str(exc), ").")
+            smda_report = self._createErrorReport(start, exc)
+        return smda_report
+
+    def disassembleUnmappedBuffer(self, file_content):
+        loader = MemoryFileLoader(file_content, map_file=True)
+        file_content = loader.getData()
+        binary_info = BinaryInfo(file_content)
+        binary_info.raw_data = loader.getRawData()
+        binary_info.file_path = ""
+        binary_info.base_addr = loader.getBaseAddress()
+        binary_info.bitness = loader.getBitness()
+        binary_info.code_areas = loader.getCodeAreas()
+        start = datetime.datetime.utcnow()
+        try:
+            smda_report = self._disassemble(binary_info, timeout=self.config.TIMEOUT)
+            if self.config.STORE_BUFFER:
+                smda_report.buffer = file_content
+        except Exception as exc:
+            LOGGER.error("An error occurred while disassembling unmapped buffer.")
+            # print("-> an error occured (", str(exc), ").")
             smda_report = self._createErrorReport(start, exc)
         return smda_report
 
@@ -64,7 +92,8 @@ class Disassembler(object):
             if self.config.STORE_BUFFER:
                 smda_report.buffer = file_content
         except Exception as exc:
-            print("-> an error occured (", str(exc), ").")
+            LOGGER.error("An error occurred while disassembling buffer.")
+            # print("-> an error occured (", str(exc), ").")
             smda_report = self._createErrorReport(start, exc)
         return smda_report
 
@@ -79,5 +108,5 @@ class Disassembler(object):
         report.smda_version = self.config.VERSION
         report.status = "error"
         report.execution_time = self._getDurationInSeconds(start, datetime.datetime.utcnow())
-        report.message = traceback.format_exc(exception)
+        report.message = traceback.format_exc()
         return report
